import QtQuick 2.0

Item {
    id: root
    property string firmwarePackageName: "candor-firmware"
    property bool updatingPackages: false
    property bool updatingFirmware: false
    property string installedFirmwareFile: ""

    /*
    available states are:
    idle, updatingPackages, updatingFirmware
    */
    property string state: "idle"
    property bool firmwareAvailable: false
    property bool busy: state !== "idle"

    signal startFirmwareAutoLoad()

    function checkHexFileUpdate() {
        var hexfiles = storageMgr.listFiles("/data/firmware/", "*.hex")
        if(hexfiles.length > 0) {
            root.installedFirmwareFile = "/data/firmware/" + hexfiles[0]
        }
    }

    function brainboardVersion(version) {
        return version.substr(0, version.lastIndexOf("."))
    }

    function versionFromFilename(filename) {
        if(!filename)
            return ""
        var parts = filename.split("/")
        if(parts.length <= 0)
            return 0;
        parts = parts[parts.length-1].split(".")
        parts = parts[0].split("_")
        var version = parts[1] + "." + parts[2]
        if(parts.length > 3)
            version += "." + parts[3]

        return version
    }

    function firmwareUpdateAvailable() {
        checkHexFileUpdate()
        if (root.installedFirmwareFile === "")
            return false

        if (machineinfo.brainboardFirmwareVersion === "")
            return false

        console.log("FirmwareAutoLoadModule: Available: " + versionFromFilename(root.installedFirmwareFile) + " Current: " + brainboardVersion(machineinfo.brainboardFirmwareVersion))
        return (versionFromFilename(root.installedFirmwareFile) !== brainboardVersion(machineinfo.brainboardFirmwareVersion))
    }

    onUpdatingPackagesChanged: {
        switch(state) {
        case "idle":
            if(updatingPackages === true)
            state = "updatingPackages"
            console.log("FirmwareAutoLoadModule change state: " + state)
            break;
        case "updatingPackages":
            if(updatingPackages === false) {
                if(firmwareUpdateAvailable() === true) {
                    state = "updatingFirmware"
                    console.log("FirmwareAutoLoadModule change state: " + state)
                    startFirmwareAutoLoad()
                } else {
                    state = "idle"
                    console.log("FirmwareAutoLoadModule change state: " + state)
                }
            }

            break;
        }
    }

    onUpdatingFirmwareChanged: {
        switch(state) {
        case "updatingFirmware":
            if(updatingFirmware === false) {
                state = "idle"
                console.log("FirmwareAutoLoadModule change state: " + state)
            }

            break;

        }
    }
}
