import QtQuick 2.4
import Components 1.0
import Process 0.1

ConfirmationPrompt {
    id: root

    property bool active: root.visible || statusPopup.visible || noUpdatesFoundPopup.visible
    state: "Confirm"

    function showPrompt() {
        if (state != "Confirm" && state != "Finished") {
            return
        }

        state = "Confirm"
        show()
    }

    z: 999999

    onYesClicked: {
        if (tv_window.visible) {
            tv_window.hide()
        }
        if (ipod_window.visible) {
            ipod_window.close()
        }

        console.log("Update!")
        root.hide()
        statusPopup.show()
        state = "Disconnect" // Disconnect the network
    }

    Process {
        id: enableDisableNetwork
        program: "scripts/enable_disable_network.sh"
        arguments: ["0"] // 0=Off, 1=On
        onFinished: {
            if (state === "Disconnect") {
                state = "CheckUpdates"
            } else if (state === "Reconnect") {
                state = "Finished"
            } else if (state === "Error") {
                // Do nothing - Keep popup shown
            } else {
                console.log("enableDisableNetwork: Unknown state:", state)
            }
        }
    }

    // The following process gathers a list of packages that may be updated
    Process {
        id: checkUpdates
        property string packages

        program: "bash"
        arguments: [ "scripts/list_upgrades.sh" ]
        onReadyReadStandardOutput: {
            packages += readAllStandardOutput()
        }
        onStarted: { packages = ""; console.log("checking updates") }
        onFinished: {
            console.log("packages upgradable:" + packages)
            if (packages) {
                state = "DoUpdates"
            } else {
                state = "Error" // No updates found
            }
        }
    }

    Process {
        id: updatePackages

        program: "bash"
        arguments: ["scripts/do_upgrades.sh"]

        onReadyReadStandardOutput: {
            console.log(readAllStandardOutput())
        }
        onReadyReadStandardError: {
            console.log(readAllStandardError())
        }
        onStarted: { console.log("updating packages...") }
        onFinished: {
            //checkUpdates.packages = ""
            //checkUpdates.start()
            print("Diagnostics Update: package update complete.")
            state = "Reconnect"
            main.restartRequired = true
            //restartMsg.visible = true
            //updatingDialog.hide()
            //firmwareLoader.checkHexFileUpdate() // check if any hex files were installed
        }
    }

    MessagePopup {
        id: statusPopup
        z: 999999

    }

    ModalDialog{
        id: noUpdatesFoundPopup

        property string message: qsTr("No Updates Found")
        visible: false
        z: 999999

        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 350
            source: "graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text {
                id: popupText

                anchors.fill: parent
                anchors.margins: 30
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -40
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50
                text: noUpdatesFoundPopup.message
            }

            ImageButton {
                id: close_button

                onClicked: {
                    noUpdatesFoundPopup.hide()
                    if (enableDisableNetwork.processState === Process.NotRunning) {
                        root.state = "Finished"
                    } else {
                        root.state = "Reconnect"
                    }
                }

                visible: main.isTouch
                width: 48
                height: 48
                anchors.right: parent.right
                anchors.rightMargin: 50
                anchors.top: parent.top
                anchors.topMargin: 40
                upimage: "Keypad/KeyPad_X_Large.png"
                downimage: "Keypad/KeyPad_X_Large.png"
                mouseAreaScale: 2.0


            }
        }
    }

    states: [
        State {
            name: "Confirm"
            StateChangeScript {
                script: {
                    statusPopup.hide()
                }
            }
        },
        State {
            name: "Disconnect"
            PropertyChanges { target: statusPopup; message: QT_TR_NOOP("Disconnecting From Network") }
            StateChangeScript {
                script: {
                    enableDisableNetwork.arguments = ["0"]
                    enableDisableNetwork.start()
                }
            }
        },
        State {
            name: "CheckUpdates"
            PropertyChanges { target: statusPopup; message: QT_TR_NOOP("Checking For Updates") }
            StateChangeScript {
                script: {
                    checkUpdates.start()
                }
            }
        },
        State {
            name: "Error"
            StateChangeScript {
                script: {
                    statusPopup.hide()
                    // Start reconnect early, don't show popup.
                    enableDisableNetwork.arguments = ["1"]
                    enableDisableNetwork.start()

                    noUpdatesFoundPopup.show()
                }
            }
        },
        State {
            name: "DoUpdates"
            PropertyChanges { target: statusPopup; message: QT_TR_NOOP("Updating Software...") }
            StateChangeScript {
                script: {
                    updatePackages.start()
                }
            }
        },
        State {
            name: "Reconnect"
            PropertyChanges { target: statusPopup; message: QT_TR_NOOP("Please Wait. Reconnecting to Network") }
            StateChangeScript {
                script: {
                    statusPopup.show()
                    if (enableDisableNetwork.processState === Process.NotRunning) {
                        enableDisableNetwork.arguments = ["1"]
                        enableDisableNetwork.start()
                    }
                }
            }
        },

        State {
            name: "Finished"
            StateChangeScript {
                script: {
                    noUpdatesFoundPopup.hide()
                    statusPopup.hide()
                    //main.restartRequired = true
                }
            }
        }
    ]
}
