// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import ".."

Item {
    id: root
    width: 1000
    height: 406

    ListModel {
        id: c360Modes_LateralTrainer

        function imagePath(productModel) {
            var model = machineinfo.modelString ? machineinfo.modelString : "TL1000"
            switch(machineinfo.modelString) {
            // TODO implement for TL1000 - TFT
            default:
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS400/C360_XCS400_"
            }
        }

        function title(index) {
            return [ qsTr("START UP, PUSH OUTWARD"),
                    qsTr("PUSH INWARD"),
                    qsTr("LEG PUMPS OUTWARD"),
                    qsTr("SQUAT INWARD"),
                    qsTr("LEG PUMPS INWARD"),
                    qsTr("STAND ON TOES, PUSH OUTWARD"),
                    qsTr("SQUAT OUTWARD"),
                    qsTr("STAND ON TOES, PUSH INWARD"),
                    qsTr("RECOVER, PUSH OUTWARD")
                    ][index]
        }

        function instructionsList(index) {
            return [
                        [qsTr("Stand on Foot Pedals") ,qsTr("Push Outward"), qsTr("Move Body Side to Side")],
                        [qsTr("Stand on Foot Pedals"),qsTr("Push Inward"), qsTr("Move Body Side to Side") ],
                        [qsTr("Center Your Upper Body") ,qsTr("Remain Centered") ,qsTr("Push Outward") ],
                        [qsTr("Squat (Knees at 90 Degrees)") ,qsTr("Center Body"), qsTr("Push Inward") ],
                        [qsTr("Center Your Upper Body") ,qsTr("Remain Centered") ,qsTr("Push Inward") ],
                        [qsTr("Stand on Toes") ,qsTr("Push Outward") ],
                        [qsTr("Squat (Knees at 90 Degrees)") ,qsTr("Center Body"), qsTr("Push Outward") ],
                        [qsTr("Stand on Toes") ,qsTr("Push Inward") ],
                        [qsTr("Stand on Foot Pedals") ,qsTr("Push Outward"), qsTr("Move Body Side to Side")],
                    ][index];
        }

        function instructions(index) {
            var instr = instructionsList(index)
            return instr.map(function(s) { return "• " + s}).join("\n")
        }

        ListElement {
            images: []
            video: "Startup, Push Outward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Push Inward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Leg Pumps Outward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Squat Inward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Leg Pumps Inward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Toe Raises Outward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Squat Outward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Toe Raises Inward.mp4"
            icon : ""
        }
        ListElement {
            images: []
            video: "Recover, Push Outward.mp4"
            icon : ""
        }
    }
    ListModel {
        id: c360Modes_Elliptical

        function imagePath(productModel) {
            var model = machineinfo.modelString ? machineinfo.modelString : "XCS900"
            switch(machineinfo.modelString) {
            case "XCS900":
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS900/C360_XCS900_"
            case "XCS400":
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS400/C360_XCS400_"
            default:
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS400/C360_XCS400_"
            }
        }

        function title(index) {
            return [ qsTr("STRIDE FORWARD"),
                    qsTr("STRIDE FORWARD & PUSH ARMS"),
                    qsTr("STAND ON SIDES, LEFT ARM ONLY"),
                    qsTr("STAND ON SIDES, RIGHT ARM ONLY"),
                    qsTr("REVERSE STRIDE & BEND KNEES"),
                    qsTr("STRIDE FORWARD & LIFT HEELS"),
                    qsTr("STRIDE FORWARD & PULL ARMS"),
                    main.isCSA ? qsTr("HOLD CENTER GRIPS, REVERSE STRIDE & LIFT TOES") : qsTr("HOLD SIDE RAILS, REVERSE STRIDE & LIFT TOES"),
                                 qsTr("STAND ON SIDES, CHANGE GRIP, PUSH & PULL ARMS"),
                                 qsTr("RECOVER - STRIDE FORWARD")
                    ][index]
        }

        function instructionsList(index) {
            return [
                        [qsTr("Feet on Foot Pedals") ,qsTr("Stride Forward")],
                        [qsTr("Stride Forward") ,qsTr("Push Arms") ],
                        [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Right Arm on Handrail") ],
                        [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Left Arm on Handrail") ],
                        [qsTr("Feet On Pedals") ,qsTr("Reverse Stride") ,qsTr("Bend Knees") ],
                        [qsTr("Stride Forward") ,qsTr("Lift Heels") ],
                        [qsTr("Feet On Pedals") ,qsTr("Stride Forward") ,qsTr("Pull Arms") ],
                        [qsTr("Reverse Stride") ,qsTr("Bend Knees") ,qsTr("Lift Toes") ],
                        [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Try Different Grip") ],
                        [qsTr("Feet on Foot Pedals") ,qsTr("Stride Forward")]
                    ][index];
        }

        function instructions(index) {
            var instr = instructionsList(index)
            return instr.map(function(s) { return "• " + s}).join("\n")
        }

        ListElement {
            images: [ ListElement { source: "motion1-1.jpg" },
                ListElement { source: "motion1-2.jpg" }
            ]
            video: "Startup, Stride Forward.mp4"
            icon : "C360_1-1_Forward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion2-1.jpg" },
                ListElement { source: "motion2-2.jpg" }
            ]
            video: "Stride Forward, Push Arms.mp4"
            icon : "C360_2-1_Forward_Push_Arms.png"
        }
        ListElement {
            images: [ ListElement { source: "motion3-1.jpg" },
                ListElement { source: "motion3-2.jpg" }
            ]
            video: "Stand on Sides, Left Arm Only.mp4"
            icon : "C360_3-1_Left_Arm.png"
        }
        ListElement {
            images: [ ListElement { source: "motion4-1.jpg" },
                ListElement { source: "motion4-2.jpg" }
            ]
            video: "Stand on Sides, Right Arm Only.mp4"
            icon : "C360_4-1_Right_Arm.png"
        }
        ListElement {
            images: [ ListElement { source: "motion5-1.jpg" },
                ListElement { source: "motion5-2.jpg" }
            ]
            video: "Reverse Stride, Bend Knees.mp4"
            icon : "C360_5-1_Reverse_Bend_Knees.png"
        }
        ListElement {
            images: [ ListElement { source: "motion6-1.jpg" },
                ListElement { source: "motion6-2.jpg" }
            ]
            video: "Stride Forward, Lift Heels.mp4"
            icon : "C360_6-1_Forward_Heels.png"
        }
        ListElement {
            images: [ ListElement { source: "motion7-1.jpg" },
                ListElement { source: "motion7-2.jpg" }
            ]
            video: "Stride Forward, Pull Arms.mp4"
            icon : "C360_7-1_Forward_Pull_Arms.png"
        }
        ListElement {
            images: [ ListElement { source: "motion8-1.jpg" },
                ListElement { source: "motion8-2.jpg" }
            ]
            video: "Hold HRC Handles, Reverse Stride, Lift Toes.mp4"
            icon : "C360_8-1_Hold_Side_Rails.png"
        }
        ListElement {
            images: [ ListElement { source: "motion9-1.jpg" },
                ListElement { source: "motion9-2.jpg" }
            ]
            video: "Stand on Sides, Push and Pull Arms.mp4"
            icon : "C360_9-1_Stand_On_Sides.png"
        }
        ListElement {
            images: [ ListElement { source: "motion10-1.jpg" },
                ListElement { source: "motion10-2.jpg" }
            ]
            video: "Recover, Stride Forward.mp4"
            icon : "C360_10-1_Recover.png"
        }
    }

    Loader {
        anchors.fill: parent

        sourceComponent: main.isCSA || main.isLateralTrainer ? c360VideoViewComponent : c360ViewComponent
    }

    Component {
        id: c360ViewComponent

        C360View {
            id: c360View
            width: 1000
            height: 406
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            onPhaseTitleChanged: workoutScreen.showC360Message(title)
        }
    }

    Component {
        id: c360VideoViewComponent

        VideoWorkoutView {
            anchors.fill: parent
            Connections {
                target: workoutScreen
                onWorkoutStopped: {
                    videoWorkout.stopVideo()
                }
            }
            onPhaseTitleChanged: workoutScreen.showC360Message(text)
        }
    }
}
